import React, { FC, useState, useCallback, useEffect } from 'react';
import { Picker } from '@ray-js/smart-ui';
import { getMinutesBySplit5 } from '@/utils';
// import clsx from 'clsx';
import OwModal from '../OwModal';
import styles from './index.module.less';

type Props = {
  show?: boolean;
  initData: any;
  onCancel: any;
  onAfterOk: any;
  pickerArr?: any;
  modalTitle?: any;
  onAfterChange?: any;
  isTimePick?: boolean;
  isMultiColumn?: boolean; //是否多列
};

const columns12 = [
  {
    values: ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12'],
  },
  {
    values: getMinutesBySplit5(),
  },
  {
    values: ['AM', 'PM'],
  },
];

const columns24 = [
  {
    values: [
      '00',
      '01',
      '02',
      '03',
      '04',
      '05',
      '06',
      '07',
      '08',
      '09',
      '10',
      '11',
      '12',
      '13',
      '14',
      '15',
      '16',
      '17',
      '18',
      '19',
      '20',
      '21',
      '22',
      '23',
    ],
  },
  {
    values: getMinutesBySplit5(),
  },
];

const SmartPickerModal: FC<Props> = ({
  show = true, // 显示
  isTimePick,
  onCancel,
  initData,
  onAfterOk,
  pickerArr = [],
  modalTitle,
  isMultiColumn,
  onAfterChange, // 日期选择器改变触发事件
}) => {
  const { value, hour, minute, is24Hour } = initData || {};

  const [current, setCurrent] = useState<any>(pickerArr.indexOf(value));
  const [multiColumns, setMultiColumns] = useState([]);
  const [timeColumns, setTimeColumns] = useState([]);
  const [muliValue, setMuliValue] = useState(typeof value === 'string' ? value.split(' ') : []);

  useEffect(() => {
    if (isMultiColumn) {
      const valArr = muliValue;
      const columns = pickerArr.map((cur, inx) => {
        return { values: pickerArr[inx], activeIndex: cur.indexOf(valArr[inx]) };
      });
      setMultiColumns(columns);
    }
  }, [pickerArr]);

  useEffect(() => {
    if (isTimePick) {
      let columns = [];
      if (is24Hour) {
        columns = columns24.map((cur, inx) => {
          const act = inx === 0 ? hour : minute;
          return { ...cur, activeIndex: cur.values.indexOf(act) };
        });
      } else {
        const numH = Number(hour);
        let realH = numH,
          unit = 'AM';
        if (numH > 12) {
          realH -= 12;
          unit = 'PM';
        }
        if (numH === 12) {
          unit = 'PM';
        }
        if (numH === 0) {
          realH = 12;
        }

        const realHStr = realH.toString().padStart(2, '0');
        columns = columns12.map((cur, inx) => {
          let act = minute;
          if (inx === 0) {
            act = realHStr;
          }
          if (inx === 2) {
            act = unit;
          }
          return { ...cur, activeIndex: cur.values.indexOf(act) };
        });
      }
      setTimeColumns(columns);
    }
  }, []);

  const onMuliChange = event => {
    const { value } = event.detail;
    setMuliValue(value);
    const indexArr = value.map((cur, inx) => multiColumns[inx].values.indexOf(cur));
    onAfterChange && onAfterChange(indexArr);
  };

  const onSmartPickChange = event => {
    const { value, index } = event.detail;
    setCurrent(index);
    console.log(value, index, 'onSmartPickChange');
    onAfterChange && onAfterChange(value);
  };

  const onTimeChange = event => {
    const { value } = event.detail;
    //  console.log(value, 'onTimeChange');
    setCurrent(value);
  };

  const onOk = () => {
    // 兼容多维数据源
    let pickValue, timeState;
    if (isMultiColumn) {
      pickValue = muliValue.join(' ');
    } else if (isTimePick) {
      if (current !== -1) {
        const h = Number(current[0]);
        let hourTemp = !is24Hour && current[2] === 'PM' && h > 12 ? h + 12 : h;
        //  console.log(current, 'isTimePick');
        if (!is24Hour && current[2] === 'AM' && h === 12) {
          hourTemp = 0;
        }
        timeState = {
          hour: hourTemp,
          minute: Number(current[1]),
        };

        onAfterOk({ pickValue, timeState });
      }
      return;
    } else {
      pickValue = pickerArr[current];
    }

    console.log(pickValue, 'pickValue onAfterOk');

    onAfterOk({ pickValue });
  };

  return (
    <OwModal show={show} onCancel={onCancel} onOk={onOk} modalTitle={modalTitle}>
      {isTimePick ? (
        <Picker
          columns={timeColumns}
          itemHeight={45}
          onChange={onTimeChange}
          customClass={styles.smartPickerWrap}
          visibleItemCount={4}
        />
      ) : (
        <Picker
          columns={isMultiColumn ? multiColumns : pickerArr}
          itemHeight={45}
          activeIndex={current}
          onChange={isMultiColumn ? onMuliChange : onSmartPickChange}
          customClass={styles.smartPickerWrap}
          visibleItemCount={4}
        />
      )}
    </OwModal>
  );
};

export default SmartPickerModal;
